@@ -1,6 +1,9 @@
 package XML::Grammar::Fiction::FromProto::Node::Description;
 
-our $VERSION = '0.14.7';
+use strict;
+use warnings;
+
+our $VERSION = '0.14.8';
 
 use MooX 'late';
 
@@ -16,7 +19,7 @@ __END__
 
 =head1 VERSION
 
-version 0.14.7
+version 0.14.8
 
 =head1 AUTHOR
 
