@@ -1,5 +1,8 @@
 package XML::Grammar::FictionBase::Event;
 
+use strict;
+use warnings;
+
 
 use MooX 'late';
 
@@ -10,7 +13,7 @@ has 'tag' => (isa => "Maybe[Str]", is => "ro", predicate => '_has_tag',);
 has 'elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 has 'tag_elem' => (isa => "Maybe[XML::Grammar::Fiction::FromProto::Node]", is => "ro");
 
-our $VERSION = '0.14.7';
+our $VERSION = '0.14.8';
 
 sub is_tag_of_name
 {
@@ -49,7 +52,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.14.7
+version 0.14.8
 
 =head1 VERSION
 
