@@ -1,8 +1,11 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
 
+use strict;
+use warnings;
+
 use MooX 'late';
 
-our $VERSION = '0.14.7';
+our $VERSION = '0.14.8';
 
 use XML::Writer;
 use HTML::Entities ();
@@ -434,11 +437,11 @@ to XML converters.
 
 =head1 VERSION
 
-version 0.14.7
+version 0.14.8
 
 =head1 VERSION
 
-Version 0.14.7
+Version 0.14.8
 
 =head2 $self->convert({ source => { file => $path_to_file } })
 
