@@ -1,5 +1,8 @@
 package XML::Grammar::Screenplay::ToDocBook;
 
+use strict;
+use warnings;
+
 use MooX 'late';
 
 use XML::GrammarBase::Role::RelaxNG v0.2.2;
@@ -17,7 +20,7 @@ has '+to_docbook_xslt_transform_basename' =>
 );
 
 
-our $VERSION = '0.14.7';
+our $VERSION = '0.14.8';
 
 
 
@@ -45,7 +48,7 @@ XML to DocBook.
 
 =head1 VERSION
 
-version 0.14.7
+version 0.14.8
 
 =head1 METHODS
 
@@ -55,7 +58,7 @@ Inherited - (to settle pod-coverage).
 
 =head1 VERSION
 
-Version 0.14.7
+Version 0.14.8
 
 =head2 new()
 
