@@ -1,5 +1,8 @@
 package XML::Grammar::Screenplay::ToHTML;
 
+use strict;
+use warnings;
+
 use MooX 'late';
 
 use XML::GrammarBase::Role::RelaxNG v0.2.2;
@@ -17,7 +20,7 @@ has '+to_html_xslt_transform_basename' =>
 );
 
 
-our $VERSION = '0.14.7';
+our $VERSION = '0.14.8';
 
 
 sub translate_to_html
@@ -44,11 +47,11 @@ XML to HTML.
 
 =head1 VERSION
 
-version 0.14.7
+version 0.14.8
 
 =head1 VERSION
 
-Version 0.14.7
+Version 0.14.8
 
 =head1 METHODS
 
